<?php

namespace Litecms\Leasing\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Leasing\Actions\LeaseAction;
use Litecms\Leasing\Http\Requests\LeaseActionRequest;
use Litecms\Leasing\Http\Resources\LeaseResource;
use Litecms\Leasing\Models\Lease;

/**
 * Admin web controller class.
 */
class LeaseActionController extends BaseController
{

    /**
     * Action controller function for lease.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LeaseActionRequest $request, Lease $lease, $action)
    {
        try {
            $request = $request->all();
            $lease = LeaseAction::run($action, $lease, $request);

            $data = new LeaseResource($lease);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('leasing::lease.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('leasing/lease/' . $lease->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leasing/lease/' . $lease->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
