<?php

namespace Litecms\Leasing\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Leasing\Http\Requests\LeaseActionsRequest;
use Litecms\Leasing\Actions\LeaseActions;

/**
 * Admin web controller class.
 */
class LeaseActionsController extends BaseController
{

    /**
     * Action controller function for lease.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LeaseActionsRequest $request, $action)
    {
        try {
            $lease = LeaseActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('leasing::lease.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('leasing/lease/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leasing/lease/' . $action))
                ->redirect();
        }
    }
}
