<?php

namespace Litecms\Leasing\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Leasing\Events\LeaseAction as LeaseActionEvent;
use Litecms\Leasing\Notifications\LeaseAction as LeaseActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LeaseAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LeaseActionEvent.
     *
     * @param   LeaseActionEvent  $event
     * @return mixed
     */
    public function handle(LeaseActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $lease.
     *
     * @param   LeaseActionEvent  $event
     * @return void
     */
    public function create(LeaseActionEvent $event)
    {
        $client = $event->lease->client;
        Notification::send($client, new LeaseActionNotification($event));
    }

    /**
     * Handle the LeaseActionEvent as a listener.
     *
     * @param   LeaseActionEvent  $event
     * @return mixed
     */
    public function asListener(LeaseActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LeaseActionEvent  $event
     * @return bool
     */
    private function isAllowed(LeaseActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
