<?php

namespace Litecms\Leasing\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Leasing\Events\LeaseWorkflow as LeaseWorkflowEvent;
use Litecms\Leasing\Notifications\LeaseWorkflow as LeaseWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class LeaseWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(LeaseWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $lease is submitted.
     *
     * @param LeaseWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(LeaseWorkflowEvent $event)
    {
        $client = $event->lease->client;
        Notification::send($client, new LeaseWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $lease is published.
     *
     * @param LeaseWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(LeaseWorkflowEvent $event)
    {
        $client = $event->lease->client;
        Notification::send($client, new LeaseWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $lease is approved.
     *
     * @param LeaseWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(LeaseWorkflowEvent $event)
    {
        $client = $event->lease->client;
        Notification::send($client, new LeaseWorkflowNotification($event));
    }

    /**
     * Handles the $lease workflow event as a listener.
     *
     * @param LeaseWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(LeaseWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
