<?php
namespace Litecms\Leasing\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Leasing\Events\LeaseAction as LeaseActionEvent;
use Litecms\Leasing\Models\Lease;

class LeaseAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $lease;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LeaseActionEvent $lease
     */
    public function __construct(LeaseActionEvent $lease)
    {
        $this->action = $event->action;
        $this->lease = $lease;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Lease Approved - ' . config('app.name'))
            ->view('leasing::lease.email.action', ['data' => $this->lease]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
