<?php

namespace Litecms\Leasing\Policies;

use Litecms\Leasing\Models\Lease;
use Litepie\User\Interfaces\UserPolicyInterface;

trait LeaseAction
{

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('leasing.lease.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Lease $lease) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('leasing.lease.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('leasing.lease.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Lease $lease)
    {


        if ($authUser->canDo('leasing.lease.action.delete')) {
            return true;
        }

        return false;
    }


}
