<?php

namespace Litecms\Leasing\Policies;

use Litecms\Leasing\Models\Lease;
use Litepie\User\Interfaces\UserPolicyInterface;

trait LeaseWorkflow
{

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->canDo('leasing.lease.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function submit(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->canDo('leasing.lease.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function publish(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->canDo('leasing.lease.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unpublish(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->canDo('leasing.lease.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function archive(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->canDo('leasing.lease.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function unarchive(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->canDo('leasing.lease.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lease.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function reject(UserPolicyInterface $authUser, Lease $lease)
    {
        if ($authUser->canDo('leasing.lease.reject')) {
            return true;
        }

        return false;
    }

}
